@@ -3,8 +3,13 @@ import os
 import time
 
 
-# Function for deleting old files
-def delete_old_files(folder, ageTime):
+def delete_old_files(folder: str, ageTime: int) -> str:
+    """
+    Function for deleting old files
+    :param folder: path to folder
+    :param ageTime: time to control
+    :return: logs: result of function
+    """
     logs = ''
     global TOTAL_DELETED_FILE
     global TOTAL_DELETED_SIZE
@@ -21,8 +26,13 @@ def delete_old_files(folder, ageTime):
     return logs
 
 
-# Function for deleting empty folders
-def delete_empty_dir(folder, logs):
+def delete_empty_dir(folder: str, logs: str) -> str:
+    """
+    Function for deleting empty folders
+    :param folder: path to folder
+    :param logs: early logs
+    :return: logs: new logs
+    """
     logs_in = logs
     global TOTAL_DELETED_DIRS
     empty_folders_in_this_run = 0
@@ -43,8 +53,13 @@ TOTAL_DELETED_FILE = 0  # Total deleted files
 TOTAL_DELETED_DIRS = 0  # Total deleted empty folders
 
 
-# Main function
 def cleaner(FOLDERS=None, DAYS=None):
+    """
+    Main function of cleaning
+    :param FOLDERS: list of folders
+    :param DAYS: number of days
+    :return: nothin to return
+    """
     if not isinstance(FOLDERS, list):
         raise TypeError('Folders must be as list')
     if not DAYS:
@@ -58,11 +73,11 @@ def cleaner(FOLDERS=None, DAYS=None):
         logs += delete_empty_dir(folder, '')           # Delete empty folders
     finishtime = time.asctime()
 
-    print(f"START TIME: {starttime}")
-    print(f"Total deleted size: {TOTAL_DELETED_SIZE/1024/1024} MB")
-    print(f"Total deleted files: {TOTAL_DELETED_FILE}")
-    print(f"Total deleted empty folders: {TOTAL_DELETED_DIRS}")
-    print(f"FINISH TIME: {finishtime}")
+    print(f'START TIME: {starttime}')
+    print(f'Total deleted size: {TOTAL_DELETED_SIZE/1024/1024} MB')
+    print(f'Total deleted files: {TOTAL_DELETED_FILE}')
+    print(f'Total deleted empty folders: {TOTAL_DELETED_DIRS}')
+    print(f'FINISH TIME: {finishtime}')
 
     f = open('./logs.txt', 'w')
     f.write(logs)
