@@ -5,15 +5,24 @@ import shutil
 import zipfile
 
 
-# Function for converting time from timestamp
-def convert_date(timestamp):
+def convert_date(timestamp: datetime) -> str:
+    """
+    Function for converting time from timestamp
+    :param timestamp: file timestamp
+    :return: formated_date: this time in better format
+    """
     d = datetime.utcfromtimestamp(timestamp)
     formated_date = d.strftime('%d %b %Y, %H %M')
     return formated_date
 
 
-# Function that creates archive
 def create_zip(files=None, path=None):
+    """
+    Create zip-archive from files in path
+    :param files: list of files paths
+    :param path: path where to create zip-archive
+    :return: nothing to return
+    """
     if not files or not path:
         raise NameError('Required list of files and path')
     with zipfile.ZipFile(path, 'a') as new_zip:
@@ -21,16 +30,24 @@ def create_zip(files=None, path=None):
             new_zip.write(name)
 
 
-# Function that returns list of files from archive
-def files_in_zip(path=None):
+def files_in_zip(path=None) -> list:
+    """
+    Function that returns list of files from archive
+    :param path: path to zip-archive
+    :return: list of files in archive
+    """
     if not path:
         raise NameError('Required path to archive')
     with zipfile.ZipFile(path, 'r') as zipobj:
         return zipobj.namelist()
 
 
-# Function that prints information about archive
 def read_zip(path=None):
+    """
+    Function that prints information about archive
+    :param path: path to zip-archive
+    :return: nothing to return
+    """
     if not path:
         raise NameError('Required path to archive')
     with zipfile.ZipFile(path, 'r') as zipobj:
@@ -42,8 +59,13 @@ def read_zip(path=None):
             Filesize: {int(bar_info.file_size) / 1024} in KB""")
 
 
-# Function that extracts files from archive
 def extract(path_to_zip=None, path_to_file=None):
+    """
+    Function that extracts files from archive
+    :param path_to_zip: path to zip-archive
+    :param path_to_file: path to file in zip-archive
+    :return: nothing to return
+    """
     if not path_to_file or not path_to_zip:
         raise NameError('Required path to both arguments')
     data_zip = zipfile.ZipFile(path_to_zip, 'r')
@@ -54,8 +76,12 @@ def extract(path_to_zip=None, path_to_file=None):
     data_zip.close()
 
 
-# Function for reading the single file
-def read_file(path=None):
+def read_file(path=None) -> str:
+    """
+    Function for reading the single file
+    :param path: path to the file
+    :return: data: data from the file
+    """
     if not path:
         raise NameError('Required path to the file')
     with open(path, 'r') as f:
@@ -63,16 +89,25 @@ def read_file(path=None):
     return data
 
 
-# Function for writing data in the single file
 def write_file(path=None, data=None):
+    """
+    Function for writing data in the single file
+    :param path: path to the file
+    :param data: data needs be in the file
+    :return: nothing to return
+    """
     if not path or not data:
         raise NameError('Required path to the file and data')
     with open(path, 'w') as f:
         f.write(str(data))
 
 
-# Function that returns list of dirs
-def list_dir(path=None):
+def list_dir(path=None) -> list:
+    """
+    Function that returns list of dirs
+    :param path: path to the dir
+    :return: dirs: list of the dirs
+    """
     if not path:
         raise NameError('Required path to dir')
     dirs = []
@@ -82,8 +117,12 @@ def list_dir(path=None):
     return dirs
 
 
-# Function that returns list of files
-def get_files(path):
+def get_files(path: str) -> list:
+    """
+    Function that returns list of files
+    :param path: path to the dir
+    :return: files: list of the files
+    """
     if not path:
         raise NameError('Required path to dir')
     files = []
@@ -99,8 +138,13 @@ def get_files(path):
     return files
 
 
-# Main function for synchronize two folders
 def sync(path_a=None, path_b=None):
+    """
+    Main function for synchronize two folders
+    :param path_a: path to the first directory
+    :param path_b: path to the second directory
+    :return: nothing to return
+    """
     if not path_a or not path_b:
         raise NameError('Required path to both dirs')
     logs = ''
@@ -125,15 +169,23 @@ def sync(path_a=None, path_b=None):
     write_file('./logs.txt', logs)
 
 
-# Function that prints list of files and their last modified date
 def files(path=None):
+    """
+    Function that prints list of files and their last modified date
+    :param path: path to the directory
+    :return: nothing to return
+    """
     files = get_files(path)
     for file_ in files:
         print(f"{file_['name']}\t Last Modified: {file_['date_str']}")
 
 
-# Function that prints list of dirs
-def dirs(path):
+def dirs(path: str):
+    """
+    Function that prints list of dirs
+    :param path: path to the directory
+    :return: nothing to return
+    """
     dirs = list_dir(path)
     for dir_ in dirs:
         print(dir_)
