@@ -3,14 +3,15 @@
 import shutil
 import os
 
-"""
-List of arguments in the function
-<log-file name> <limit in KB> <logs-files>
-"""
-
 
 # Main function
 def purgelog(*args):
+    """
+    List of arguments in the function
+    <log-file name> <limit in KB> <logs-files>
+    :param args: arguments above
+    :return: nothing to return
+    """
     if len(args) < 3:
         raise NameError('Missing arguments')
 
@@ -29,11 +30,11 @@ def purgelog(*args):
                     dst = str(currentFileNum) + '_' + file_name
                     if os.path.isfile(src):
                         shutil.copyfile(src, dst)
-                        print(f"Copied: {src} to {dst}")
+                        print(f'Copied: {src} to {dst}')
 
                 # Copy the data in the next file
                 shutil.copyfile(file_name, '1_' + file_name)
-                print(f"Copied: {file_name} to 1_{file_name}")
+                print(f'Copied: {file_name} to 1_{file_name}')
             # Make empty file
             myfile = open(file_name, 'w')
             myfile.close()
